@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,17 +36,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssociateAccessGroups", params)
+            headers = request.headers
+            body = self.call("AssociateAccessGroups", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.AssociateAccessGroupsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.AssociateAccessGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -64,17 +59,35 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccessGroup", params)
+            headers = request.headers
+            body = self.call("CreateAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateAccessRules(self, request):
+        """批量创建权限规则，权限规则ID和创建时间无需填写。
+
+        :param request: Request instance for CreateAccessRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.CreateAccessRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.CreateAccessRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAccessRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -92,17 +105,35 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFileSystem", params)
+            headers = request.headers
+            body = self.call("CreateFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateLifeCycleRules(self, request):
+        """批量创建生命周期规则，生命周期规则ID和创建时间无需填写。
+
+        :param request: Request instance for CreateLifeCycleRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.CreateLifeCycleRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.CreateLifeCycleRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLifeCycleRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -120,17 +151,150 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMountPoint", params)
+            headers = request.headers
+            body = self.call("CreateMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.CreateMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateRestoreTasks(self, request):
+        """批量创建回热任务，回热任务ID、状态和创建时间无需填写。
+
+        :param request: Request instance for CreateRestoreTasks.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.CreateRestoreTasksRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.CreateRestoreTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateRestoreTasks", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateRestoreTasksResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteAccessGroup(self, request):
+        """删除权限组。
+
+        :param request: Request instance for DeleteAccessGroup.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DeleteAccessGroupRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DeleteAccessGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAccessGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteAccessRules(self, request):
+        """批量删除权限规则。
+
+        :param request: Request instance for DeleteAccessRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DeleteAccessRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DeleteAccessRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAccessRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteFileSystem(self, request):
+        """删除文件系统，不允许删除非空文件系统。
+
+        :param request: Request instance for DeleteFileSystem.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DeleteFileSystemRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DeleteFileSystemResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteFileSystem", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteLifeCycleRules(self, request):
+        """批量删除生命周期规则。
+
+        :param request: Request instance for DeleteLifeCycleRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DeleteLifeCycleRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DeleteLifeCycleRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteLifeCycleRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteMountPoint(self, request):
+        """删除挂载点。
+
+        :param request: Request instance for DeleteMountPoint.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DeleteMountPointRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DeleteMountPointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteMountPoint", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -148,17 +312,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessGroup", params)
+            headers = request.headers
+            body = self.call("DescribeAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -176,17 +335,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessGroups", params)
+            headers = request.headers
+            body = self.call("DescribeAccessGroups", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAccessGroupsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeAccessGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -204,17 +358,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessRules", params)
+            headers = request.headers
+            body = self.call("DescribeAccessRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAccessRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -232,17 +381,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystem", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -260,17 +404,35 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystems", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystems", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFileSystemsResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DescribeFileSystemsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeLifeCycleRules(self, request):
+        """通过文件系统ID查看生命周期规则列表。
+
+        :param request: Request instance for DescribeLifeCycleRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DescribeLifeCycleRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DescribeLifeCycleRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLifeCycleRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -288,17 +450,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoint", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -316,17 +473,58 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoints", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoints", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeMountPointsResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.DescribeMountPointsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeResourceTags(self, request):
+        """通过文件系统ID查看资源标签列表。
+
+        :param request: Request instance for DescribeResourceTags.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DescribeResourceTagsRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DescribeResourceTagsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeResourceTags", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeResourceTagsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeRestoreTasks(self, request):
+        """通过文件系统ID查看回热任务列表。
+
+        :param request: Request instance for DescribeRestoreTasks.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.DescribeRestoreTasksRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.DescribeRestoreTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRestoreTasks", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRestoreTasksResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -344,17 +542,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DisassociateAccessGroups", params)
+            headers = request.headers
+            body = self.call("DisassociateAccessGroups", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DisassociateAccessGroupsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DisassociateAccessGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -372,17 +565,35 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccessGroup", params)
+            headers = request.headers
+            body = self.call("ModifyAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.ModifyAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyAccessRules(self, request):
+        """批量修改权限规则属性，需要指定权限规则ID，支持修改权限规则地址、访问模式和优先级。
+
+        :param request: Request instance for ModifyAccessRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.ModifyAccessRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.ModifyAccessRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAccessRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -400,17 +611,35 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyFileSystem", params)
+            headers = request.headers
+            body = self.call("ModifyFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
+            model = models.ModifyFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
             else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyLifeCycleRules(self, request):
+        """批量修改生命周期规则属性，需要指定生命周期规则ID，支持修改生命周期规则名称、路径、转换列表和状态。
+
+        :param request: Request instance for ModifyLifeCycleRules.
+        :type request: :class:`tencentcloud.chdfs.v20201112.models.ModifyLifeCycleRulesRequest`
+        :rtype: :class:`tencentcloud.chdfs.v20201112.models.ModifyLifeCycleRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyLifeCycleRules", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -428,17 +657,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyMountPoint", params)
+            headers = request.headers
+            body = self.call("ModifyMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -456,17 +680,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyResourceTags", params)
+            headers = request.headers
+            body = self.call("ModifyResourceTags", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyResourceTagsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyResourceTagsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
